==> haskell-optparse-simple-0.1.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.0
id: optparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
key: optparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 4d0542cecb60e2fae046b11f8eed9be9
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.1/site-local/optparse-simple-0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/optparse-simple-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/optparse-simple-0.1.0
hs-libraries: HSoptparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
depends:
    base-4.12.0.0 gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
    optparse-applicative-0.14.3.0-IKaF2mgRPI37cniOJkqr8k
    template-haskell-2.14.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.0
id: optparse-simple-0.1.0-Fp3LVzchbfXCqy0sUyxJCz
key: optparse-simple-0.1.0-Fp3LVzchbfXCqy0sUyxJCz
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: acd99c803936935ea2df6628a6cb308c
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/optparse-simple-0.1.0
hs-libraries: HSoptparse-simple-0.1.0-Fp3LVzchbfXCqy0sUyxJCz
depends:
    base-4.12.0.0 gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U
    template-haskell-2.14.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
